/* Copyright (c) 2002-2017 Pigeonhole authors, see the included COPYING file
 */

#ifndef __EXT_DEBUG_COMMON_H
#define __EXT_DEBUG_COMMON_H

/*
 * Extensions
 */

extern const struct sieve_extension_def vnd_debug_extension;

/*
 * Commands
 */

extern const struct sieve_command_def debug_log_command;

/*
 * Operations
 */

extern const struct sieve_operation_def debug_log_operation;

#endif /* __EXT_DEBUG_COMMON_H */
